import { QueryTableSource } from '@yukawa/chain-base-angular-store';
import { BehaviorSubject } from 'rxjs';
import { EventEmitter, isDevMode, Component, ViewEncapsulation, Inject, forwardRef, Input, Output, ViewChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { MatPaginator, MatPaginatorModule } from '@angular/material/paginator';
import { MatSort, MatSortModule } from '@angular/material/sort';
import { AccountService, AccountUtilities, RelationConfigService, RelationService, ContactLogService } from '@yukawa/chain-crm-angular-core';
import { ActivatedRoute, Router } from '@angular/router';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { FlexLayoutModule } from '@angular/flex-layout';
import { TranslateModule } from '@ngx-translate/core';
import { HttpClientModule } from '@angular/common/http';
import { CdkTableModule } from '@angular/cdk/table';
import { MatButtonModule } from '@angular/material/button';
import { MatIconModule } from '@angular/material/icon';
import { MatRippleModule } from '@angular/material/core';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatTableModule } from '@angular/material/table';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatMenuModule } from '@angular/material/menu';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatDatepickerModule } from '@angular/material/datepicker';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AccountQueryStore extends QueryTableSource {
    /**
     * @param {?} service
     * @param {?=} paginator
     * @param {?=} sort
     * @param {?=} tableFilter
     */
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    /**
     * @protected
     * @return {?}
     */
    queryTable() {
        /** @type {?} */
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryAccount(filter);
        //   var data = {
        //       "op" : "query",
        //       "fqn" : "bf-questionnaire-data",
        //       "stamp" : "2020-08-13T20:40:23.292+0000",
        //       "rows" : 3,
        //       "hasMore" : false,
        //       "messages" : [ {
        //           "code" : "OK",
        //           "type" : "duration",
        //           "level" : 1,
        //           "text" : "OK 1ms"
        //       } ],
        //       "items" : [
        //           {"name": "SAP", "owner": "Dietmar"},
        //           {"name": "Siemens", "owner": "Joe"},
        //           {"name": "Wirecard", "owner": "Jan"}
        //       ],
        //       "took" : 1
        //   }
        // return of(data);
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    AccountQueryStore.prototype.service;
    /**
     * @type {?}
     * @protected
     */
    AccountQueryStore.prototype.paginator;
    /**
     * @type {?}
     * @protected
     */
    AccountQueryStore.prototype.sort;
    /**
     * @type {?}
     * @protected
     */
    AccountQueryStore.prototype.tableFilter;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
;
/** @type {?} */
const TAG = "AccountTableComponent";
class AccountTableComponent {
    /**
     * @param {?} service
     */
    constructor(service) {
        this.service = service;
        this.displayedColumns = ['lastName', 'firstName', 'companyName', 'role', 'preferredCommunicationChannel'];
        this.customColumns = [];
        this.action = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.customColumns && this.customColumns.length > 0) {
            /** @type {?} */
            let abc = this.customColumns.map((/**
             * @param {?} c
             * @return {?}
             */
            c => c.columnDef));
            this.displayedColumns.push(...abc);
            this.displayedColumns.push("actions");
        }
        else {
            this.displayedColumns.push("actions");
        }
        this.dataSource = new AccountQueryStore(this.service, this.paginator, this.sort, this.AccountFilter);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.action.complete();
    }
    /**
     * @param {?} keyword
     * @return {?}
     */
    reload(keyword) {
        this.AccountFilter.keyword = keyword;
        this.applyFilter(this.AccountFilter);
    }
    /**
     * @protected
     * @param {?} filter
     * @return {?}
     */
    applyFilter(filter) {
        this.dataSource.filterSubject.next(filter);
    }
    /**
     * @param {?=} type
     * @param {?=} partner
     * @return {?}
     */
    onAction(type = "", partner) {
        if (isDevMode()) {
            console.debug(TAG, "onAction", partner);
        }
        event.stopPropagation();
        this.fireAction({ type: type, partner: partner });
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
}
AccountTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'crm-account-overview-table',
                template: "<div class=\"table-layout-1\">\n    <mat-paginator color=\"accent\" #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n    </mat-paginator>\n    <mat-table #table [dataSource]=\"dataSource\" matSort matSortActive=\"lastName\" matSortDirection=\"asc\"\n        matSortDisableClear>\n        <!-- firstName Column -->\n        <ng-container matColumnDef=\"firstName\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.FIRST_NAME' | translate}}\n            </mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.firstName}}</span></mat-cell>\n        </ng-container>\n\n        <!-- lastName Column -->\n        <ng-container matColumnDef=\"lastName\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.LAST_NAME' | translate}}\n            </mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.lastName}}</span></mat-cell>\n        </ng-container>\n        <!-- companyName Column -->\n        <ng-container matColumnDef=\"companyName\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.COMPANY_NAME' | translate}}\n            </mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.companyName}}</span></mat-cell>\n        </ng-container>\n\n\n        <ng-container matColumnDef=\"partnerId\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.ID' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.info?.shortName || row.partnerId}}</span></mat-cell>\n        </ng-container>\n\n\n        <!-- role Column -->\n        <ng-container matColumnDef=\"role\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.ROLE' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.role}}</span></mat-cell>\n        </ng-container>\n\n        <!-- preferredCommunicationChannel Column -->\n        <ng-container matColumnDef=\"preferredCommunicationChannel\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.COMMUNICATION_CHANNEL' | translate}}\n            </mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.preferredCommunicationChannel}}</span></mat-cell>\n        </ng-container>\n\n        <!-- mobile Column -->\n        <ng-container matColumnDef=\"mobile\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.MOBILE' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row.mobile}}</span></mat-cell>\n        </ng-container>\n\n        <!-- Owner column -->\n        <ng-container matColumnDef=\"created.user\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.OWNER' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span>{{row?.created?.user}}</span></mat-cell>\n        </ng-container>\n\n        <!-- status -->\n        <ng-container matColumnDef=\"status\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef>{{'PARTNER.HEADER.STATUS' | translate}}</mat-header-cell>\n            <mat-cell *matCellDef=\"let row\"><span></span></mat-cell>\n        </ng-container>\n\n\n        <!-- Custom Column -->\n        <ng-container *ngFor=\"let column of customColumns\" [cdkColumnDef]=\"column.columnDef\">\n            <mat-header-cell *cdkHeaderCellDef>{{ column.header }}</mat-header-cell>\n            <mat-cell *cdkCellDef=\"let row\">{{ column.cell(row) }}</mat-cell>\n        </ng-container>\n\n\n        <!-- status -->\n        <ng-container matColumnDef=\"actions\">\n            <mat-header-cell mat-sort-header *matHeaderCellDef></mat-header-cell>\n            <mat-cell *matCellDef=\"let row\">\n                <div fxLayout=\"row\" fxLayoutAlign=\"end\">\n                    <button mat-raised-button class=\"icon-btn2 primary-50-bg\" (click)=\"onAction('delete', row)\">\n                        <mat-icon color=\"warn\">\n                            delete\n                        </mat-icon>\n                    </button>\n                </div>\n            </mat-cell>\n        </ng-container>\n\n\n        <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n        <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('edit',row)\">\n        </mat-row>\n\n    </mat-table>\n\n</div>",
                encapsulation: ViewEncapsulation.None,
                styles: ["crm-account-overview-table{width:100%}crm-account-overview-table .mat-table{background:0 0;box-shadow:none}crm-account-overview-table .mat-table .mat-row{position:relative;cursor:pointer;min-height:64px}crm-account-overview-table .mat-table .mat-cell span{width:auto!important}"]
            }] }
];
/** @nocollapse */
AccountTableComponent.ctorParameters = () => [
    { type: AccountService, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => AccountService)),] }] }
];
AccountTableComponent.propDecorators = {
    displayedColumns: [{ type: Input }],
    customColumns: [{ type: Input }],
    AccountFilter: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }]
};
if (false) {
    /** @type {?} */
    AccountTableComponent.prototype.dataSource;
    /** @type {?} */
    AccountTableComponent.prototype.displayedColumns;
    /** @type {?} */
    AccountTableComponent.prototype.customColumns;
    /** @type {?} */
    AccountTableComponent.prototype.AccountFilter;
    /** @type {?} */
    AccountTableComponent.prototype.action;
    /** @type {?} */
    AccountTableComponent.prototype.paginator;
    /** @type {?} */
    AccountTableComponent.prototype.sort;
    /**
     * @type {?}
     * @private
     */
    AccountTableComponent.prototype.service;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class RelationQueryStore extends QueryTableSource {
    /**
     * @param {?} service
     * @param {?=} paginator
     * @param {?=} sort
     * @param {?=} tableFilter
     */
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    /**
     * @protected
     * @return {?}
     */
    queryTable() {
        /** @type {?} */
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryRelation(filter);
    }
    /**
     * Only include paginator to serverMutations. Sorting should be done client side
     * @protected
     * @return {?}
     */
    initReloadMutations() {
        /** @type {?} */
        const dataMutations = [];
        if (this.paginator)
            dataMutations.push(this.paginator.page);
        if (this.filterSubject) {
            dataMutations.push(this.filterSubject);
        }
        return dataMutations;
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    RelationQueryStore.prototype.service;
    /**
     * @type {?}
     * @protected
     */
    RelationQueryStore.prototype.paginator;
    /**
     * @type {?}
     * @protected
     */
    RelationQueryStore.prototype.sort;
    /**
     * @type {?}
     * @protected
     */
    RelationQueryStore.prototype.tableFilter;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const TAG$1 = "RelationTableComponent";
class RelationTableComponent {
    /**
     * @param {?} service
     * @param {?} _route
     * @param {?} overlay
     * @param {?} _router
     */
    constructor(service, _route, overlay, _router) {
        this.service = service;
        this._route = _route;
        this.overlay = overlay;
        this._router = _router;
        //DataSource<any>;
        this.displayedColumns = ['role', 'selectedPartner', "classifier"];
        this.customColumns = [];
        this.action = new EventEmitter();
        this.relationFilter = {};
        this.PartnerId = null;
        /*        this._router.routeReuseStrategy.shouldReuseRoute = () => false;*/
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Lifecycle hooks
    // -----------------------------------------------------------------------------------------------------
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.customColumns && this.customColumns.length > 0) {
            /** @type {?} */
            let abc = this.customColumns.map((/**
             * @param {?} c
             * @return {?}
             */
            c => c.columnDef));
            this.displayedColumns.push(...abc);
            this.displayedColumns.push("actions");
        }
        else {
            this.displayedColumns.push("actions");
        }
        this._route.params.pipe().subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => {
            this.relationFilter.targetOrSourceIds = [];
            this.relationFilter.targetOrSourceIds.push(params.partnerId);
            if (this.role) {
                this.relationFilter.role = this.role;
            }
            this.PartnerId = params.partnerId;
            this.dataSource = new RelationQueryStore(this.service, this.paginator, this.sort, this.relationFilter);
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.action.complete();
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Event handlers
    // -----------------------------------------------------------------------------------------------------
    /**
     * @param {?=} type
     * @param {?=} relation
     * @return {?}
     */
    onAction(type = "", relation) {
        if (isDevMode()) {
            console.debug(TAG$1, "onAction", relation);
        }
        event.stopPropagation();
        this.fireAction({ type: type, relation: relation });
    }
    /**
     * @param {?} relId
     * @param {?} event
     * @return {?}
     */
    onDelete(relId, event) {
        event.stopPropagation();
        this.fireAction({ relId: relId, type: 'delete' });
    }
    /**
     * @return {?}
     */
    reload() {
        this.applyFilter(this.relationFilter);
    }
    /**
     * @protected
     * @param {?} filter
     * @return {?}
     */
    applyFilter(filter) {
        console.log("Appling the filter");
        this.dataSource.filterSubject.next(filter);
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
    /**
     * @param {?} id
     * @return {?}
     */
    openPartnerDetailOverlay(id) {
        this.partnerDetailsRowId = id;
    }
    // -----------------------------------------------------------------------------------------------------
    // @ Util
    // -----------------------------------------------------------------------------------------------------
    /**
     * @protected
     * @param {?} row
     * @return {?}
     */
    isPartnerSource(row) {
        if (row.sourcePartner) {
            return row.sourcePartner.partnerId === this.PartnerId;
        }
        return false;
    }
    /**
     * @param {?} row
     * @return {?}
     */
    getSelectedPartnerName(row) {
        /** @type {?} */
        let sourcePartner = row.sourcePartner;
        /** @type {?} */
        let targetPartner = row.targetPartner;
        return this.isPartnerSource(row) ? AccountUtilities.getDisplayName(targetPartner) : AccountUtilities.getDisplayName(sourcePartner);
    }
    /**
     * @param {?} row
     * @return {?}
     */
    getSelectedPartnerId(row) {
        /** @type {?} */
        let sourcePartner = row.sourcePartner;
        /** @type {?} */
        let targetPartner = row.targetPartner;
        return this.isPartnerSource(row) ? (targetPartner.partnerId) : sourcePartner.partnerId;
    }
    /**
     * @param {?} row
     * @return {?}
     */
    getDisplayedRelationName(row) {
        /** @type {?} */
        let config = RelationConfigService.getRelationConfigForRole(row.role);
        if (!config) {
            return "undefined";
        }
        return this.isPartnerSource(row) ? config.relation : config.inverseRelation;
    }
    /**
     * @param {?} row
     * @return {?}
     */
    getDisplayedClassifier(row) {
        if (!row['classifier']) {
            return "undefined";
        }
        return row.classifier;
    }
    /**
     * @param {?} row
     * @return {?}
     */
    getSelectedPartner(row) {
        /** @type {?} */
        let sourcePartner = row.sourcePartner;
        /** @type {?} */
        let targetPartner = row.targetPartner;
        return this.isPartnerSource(row) ? targetPartner : sourcePartner;
    }
    /**
     * @param {?} action
     * @return {?}
     */
    onOverlayAction(action) {
        if (action === 'close') {
            this.partnerDetailsRowId = "";
        }
    }
    /**
     * @param {?} row
     * @return {?}
     */
    navigateToPartner(row) {
        this._router.navigate(['../', this.getSelectedPartnerId(row)], { relativeTo: this._route });
    }
}
RelationTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-relation-table',
                template: "<mat-toolbar>\n    <mat-toolbar-row fxLayout fxLayoutAlign=\"space-between center\">\n\n        <ng-content></ng-content>\n\n        <mat-paginator color=\"accent\" #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n            <span>Test</span>\n        </mat-paginator>\n\n    </mat-toolbar-row>\n</mat-toolbar>\n\n\n<mat-table class=\"table-hover-1\" [dataSource]=\"dataSource\" matSort matSortActive=\"role\" matSortDirection=\"asc\"\n    matSortDisableClear>\n\n    <!-- role Column -->\n    <ng-container matColumnDef=\"role\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'RELATION.HEADER.RELATION' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"><span>{{getDisplayedRelationName(row)}}</span></mat-cell>\n    </ng-container>\n\n\n    <!-- classifier Column -->\n    <ng-container matColumnDef=\"classifier\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'RELATION.HEADER.CLASSIFIER' | translate}}\n        </mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"><span>{{row?.classifier}}</span></mat-cell>\n    </ng-container>\n\n\n\n\n    <!-- partnerSourceId Column -->\n    <ng-container matColumnDef=\"selectedPartner\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>Partner\n        </mat-header-cell>\n        <mat-cell *matCellDef=\"let row;let i = index;\">\n            <div fxLayout=\"row\" fxLayoutAlign=\"none center\">\n                <span fxFlex=\"50\">{{getSelectedPartnerName(row)}}</span>\n                <mat-icon #trigger=\"cdkOverlayOrigin\" cdkOverlayOrigin fxFlex=\"10\"\n                    (click)=\"openPartnerDetailOverlay(i); $event.stopPropagation()\" matTooltip=\"Open partner details\">\n                    info\n                </mat-icon>\n                <mat-icon #trigger=\"cdkOverlayOrigin\" cdkOverlayOrigin fxFlex=\"10\"\n                    (click)=\"navigateToPartner(row); $event.stopPropagation()\" matTooltip=\"Navigate to partner\">\n                    visibility\n                </mat-icon>\n            </div>\n            <ng-template #overlayRef (backdropClick)=\"partnerDetailsRowId = ''\" cdkConnectedOverlay\n                cdkConnectedOverlayBackdropClass=\"'backdrop'\" cdkConnectedOverlayHasBackdrop=\"true\"\n                [cdkConnectedOverlayOrigin]=\"trigger\" [cdkConnectedOverlayOpen]=\"partnerDetailsRowId === i\">\n\n                <div fxLayout=\"column\" class=\"primary-50-bg  scale-up-tl\">\n                    <div fxLayout fxLayoutAlign=\"end\" class=\"accent-A700 actions\">\n                        <mat-icon style=\"cursor:pointer; \" (click)=\"onOverlayAction('close')\">close</mat-icon>\n                    </div>\n                    <app-partner-info-view [partner]=\"getSelectedPartner(row)\" (onAction)=\"onOverlayAction($event)\">\n                    </app-partner-info-view>\n\n                </div>\n\n            </ng-template>\n\n\n        </mat-cell>\n    </ng-container>\n\n <!-- Custom Column -->\n    <ng-container *ngFor=\"let column of customColumns\" [cdkColumnDef]=\"column.columnDef\">\n        <mat-header-cell *cdkHeaderCellDef>{{ column.header }}</mat-header-cell>\n        <mat-cell *cdkCellDef=\"let row\">{{ column.cell(row) }}</mat-cell>\n      </ng-container>\n\n    <!-- delete Column -->\n    <ng-container matColumnDef=\"actions\">\n        <mat-header-cell *matHeaderCellDef></mat-header-cell>\n        <mat-cell *matCellDef=\"let row\">\n            <button mat-raised-button class=\"icon-btn2 primary-50-bg\" (click)=\"onDelete(row?.relationId, $event)\">\n                <mat-icon color=\"warn\" class=\"yukawa-navy-A700-fg\">\n                    delete\n                </mat-icon>\n            </button>\n        </mat-cell>\n    </ng-container>\n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('edit',row)\">\n    </mat-row>\n\n</mat-table>",
                encapsulation: ViewEncapsulation.None,
                styles: ["chain-relation-table{width:100%}chain-relation-table .mat-table{background:0 0;box-shadow:none}chain-relation-table .mat-table .mat-row{position:relative;cursor:pointer;min-height:64px}chain-relation-table .mat-table .mat-cell:last-child button{float:right}chain-relation-table .mat-table .mat-cell span{width:auto!important}chain-relation-table .mat-column-selectedPartner{-webkit-box-flex:0!important;flex:0 0 35%!important}"]
            }] }
];
/** @nocollapse */
RelationTableComponent.ctorParameters = () => [
    { type: RelationService, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => RelationService)),] }] },
    { type: ActivatedRoute, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => ActivatedRoute)),] }] },
    { type: Overlay, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => Overlay)),] }] },
    { type: Router, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => Router)),] }] }
];
RelationTableComponent.propDecorators = {
    dataSource: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    customColumns: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }],
    role: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    RelationTableComponent.prototype.dataSource;
    /** @type {?} */
    RelationTableComponent.prototype.displayedColumns;
    /** @type {?} */
    RelationTableComponent.prototype.customColumns;
    /** @type {?} */
    RelationTableComponent.prototype.action;
    /** @type {?} */
    RelationTableComponent.prototype.paginator;
    /** @type {?} */
    RelationTableComponent.prototype.sort;
    /** @type {?} */
    RelationTableComponent.prototype.relationFilter;
    /** @type {?} */
    RelationTableComponent.prototype.PartnerId;
    /** @type {?} */
    RelationTableComponent.prototype.role;
    /** @type {?} */
    RelationTableComponent.prototype.partnerDetailsRowId;
    /**
     * @type {?}
     * @protected
     */
    RelationTableComponent.prototype.service;
    /**
     * @type {?}
     * @private
     */
    RelationTableComponent.prototype._route;
    /** @type {?} */
    RelationTableComponent.prototype.overlay;
    /**
     * @type {?}
     * @private
     */
    RelationTableComponent.prototype._router;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContactLogQueryStore extends QueryTableSource {
    /**
     * @param {?} service
     * @param {?=} paginator
     * @param {?=} sort
     * @param {?=} tableFilter
     */
    constructor(service, paginator, sort, tableFilter) {
        super(paginator, sort, tableFilter);
        this.service = service;
        this.paginator = paginator;
        this.sort = sort;
        this.tableFilter = tableFilter;
        this.filterSubject = new BehaviorSubject(tableFilter);
    }
    /**
     * @protected
     * @return {?}
     */
    queryTable() {
        /** @type {?} */
        let filter = this.findFilter();
        this.applyFilter(filter);
        if (filter.keyword)
            filter.keyword += '*';
        return this.service.queryContactLog(filter);
    }
}
if (false) {
    /**
     * @type {?}
     * @protected
     */
    ContactLogQueryStore.prototype.service;
    /**
     * @type {?}
     * @protected
     */
    ContactLogQueryStore.prototype.paginator;
    /**
     * @type {?}
     * @protected
     */
    ContactLogQueryStore.prototype.sort;
    /**
     * @type {?}
     * @protected
     */
    ContactLogQueryStore.prototype.tableFilter;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const TAG$2 = "ContactLogTableComponent";
class ContactLogTableComponent {
    /**
     * @param {?} service
     * @param {?} _route
     */
    constructor(service, _route) {
        this.service = service;
        this._route = _route;
        this.Partners = [];
        this.displayedColumns = ['info.shortName', 'location', 'status', 'dateRange'];
        this.customColumns = [];
        this.action = new EventEmitter();
        this.contactLogFilter = {};
        //  this.dataSource =  new ContactLogQueryStore(this.service,this.paginator, this.sort)
        this._route.params.pipe().subscribe((/**
         * @param {?} params
         * @return {?}
         */
        (params) => {
            this.contactLogFilter.participantId = params.partnerId;
            this.dataSource = new ContactLogQueryStore(this.service, this.paginator, this.sort, this.contactLogFilter);
        }));
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.customColumns && this.customColumns.length > 0) {
            /** @type {?} */
            let abc = this.customColumns.map((/**
             * @param {?} c
             * @return {?}
             */
            c => c.columnDef));
            this.displayedColumns.push(...abc);
        }
        else {
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.action.complete();
    }
    /**
     * @return {?}
     */
    reload() {
        this.applyFilter(this.contactLogFilter);
    }
    /**
     * @protected
     * @param {?} filter
     * @return {?}
     */
    applyFilter(filter) {
        this.dataSource.filterSubject.next(filter);
    }
    /**
     * @param {?=} type
     * @param {?=} contactLog
     * @return {?}
     */
    onAction(type = "", contactLog) {
        event.stopPropagation();
        if (isDevMode()) {
            console.debug(TAG$2, "onAction", contactLog);
        }
        event.stopPropagation();
        this.fireAction({ type: type, contactLog: contactLog });
    }
    /**
     * @protected
     * @param {?} action
     * @return {?}
     */
    fireAction(action) {
        this.action.emit(action);
    }
    /**
     * @param {?} participantId
     * @return {?}
     */
    partnerName(participantId) {
        /** @type {?} */
        let partner = this.Partners.find((/**
         * @param {?} x
         * @return {?}
         */
        x => x.partnerId == participantId));
        return `${partner.firstName ? partner.firstName : partner.companyName} ${partner.lastName ? partner.lastName : ""}`;
    }
}
ContactLogTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'chain-contact-log-table',
                template: "\n<!-- <mat-paginator #paginator [pageIndex]=\"0\" [pageSize]=\"10\" [pageSizeOptions]=\"[5, 10, 25, 100]\">\n</mat-paginator> -->\n\n<mat-table #table [dataSource]=\"dataSource\" matSort matSortActive=\"dateRange\" matSortDirection=\"asc\" matSortDisableClear>\n\n    <!-- shortName Column -->\n    <ng-container matColumnDef=\"info.shortName\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'CONTACT_LOG.HEADER.SHORT_NAME' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> <span>{{row?.info?.shortName}}</span></mat-cell>\n    </ng-container>\n\n    <!-- communicationChannel Column -->\n    <ng-container matColumnDef=\"communicationChannel\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'CONTACT_LOG.HEADER.COMMUNICATION_CHANNEL' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> <span>{{row.communicationChannel}}</span></mat-cell>\n    </ng-container>\n\n     <!-- status Column -->\n     <ng-container matColumnDef=\"status\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'CONTACT_LOG.HEADER.STATUS' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> <span>{{row.status}}</span></mat-cell>\n    </ng-container>\n\n     <!-- location Column -->\n     <ng-container matColumnDef=\"location\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'CONTACT_LOG.HEADER.LOCATION' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> <span>{{row.location}}</span></mat-cell>\n    </ng-container>\n\n    <!-- dateRange Column -->\n    <ng-container matColumnDef=\"dateRange\">\n        <mat-header-cell mat-sort-header *matHeaderCellDef>{{'CONTACT_LOG.HEADER.DATE' | translate}}</mat-header-cell>\n        <mat-cell *matCellDef=\"let row\"> <span>{{row.dateRange?.from | date}}&nbsp;-&nbsp;{{row.dateRange?.to | date}}</span></mat-cell>\n    </ng-container>\n\n     <!-- Custom Column -->\n     <ng-container *ngFor=\"let column of customColumns\" [cdkColumnDef]=\"column.columnDef\">\n        <mat-header-cell *cdkHeaderCellDef>{{ column.header }}</mat-header-cell>\n        <mat-cell *cdkCellDef=\"let row\">{{ column.cell(row) }}</mat-cell>\n      </ng-container>\n\n   \n\n    <mat-header-row *matHeaderRowDef=\"displayedColumns\"></mat-header-row>\n    <mat-row *matRowDef=\"let row; columns: displayedColumns;\" (click)=\"onAction('edit',row)\"  >\n    </mat-row>\n\n</mat-table>\n",
                encapsulation: ViewEncapsulation.None,
                styles: ["contact-log-table{width:100%}contact-log-table .mat-table{background:0 0;box-shadow:none}contact-log-table .mat-table .mat-row{position:relative;cursor:pointer;min-height:64px}.page-inner mat-table.mat-table{background:0 0!important;margin-bottom:30px}.page-inner mat-table.mat-table mat-header-row,.page-inner mat-table.mat-table mat-row{border:0;min-height:initial}.page-inner mat-table.mat-table mat-row:nth-child(2n){background-color:#fff}.page-inner mat-table.mat-table mat-row mat-cell{color:#143c27;font-size:16px;font-weight:700;padding:15px 10px;height:initial;line-height:initial;min-height:initial}.page-inner mat-table.mat-table mat-header-row mat-header-cell:first-child,.page-inner mat-table.mat-table mat-row mat-cell:first-child{padding-left:40px}.page-inner mat-table.mat-table mat-header-row mat-header-cell:last-child,.page-inner mat-table.mat-table mat-row mat-cell:last-child{padding-right:100px}mat-table.mat-table mat-header-row{background-color:#143c27}mat-table.mat-table mat-header-row mat-header-cell{color:#fff!important;font-weight:700;font-size:16px;padding:15px 10px}.page-inner mat-table.mat-table mat-row mat-cell button span{width:auto!important;white-space:normal}.page-inner mat-table.mat-table mat-row mat-cell button{box-shadow:none!important;background-color:transparent;color:#143c27}.page-inner mat-table.mat-table mat-row mat-cell>span:not(.status){display:block;width:100px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.page-inner mat-table.mat-table mat-row mat-cell span.status{height:14px;width:14px;padding:0;line-height:initial}@media (max-width:600px){.page-inner mat-table.mat-table mat-header-row mat-header-cell:first-child,.page-inner mat-table.mat-table mat-row mat-cell:first-child{padding-left:20px}.page-inner mat-table.mat-table mat-header-row mat-header-cell:last-child,.page-inner mat-table.mat-table mat-row mat-cell:last-child{padding-right:20px}.page-inner mat-paginator,.page-inner mat-table.mat-table{width:150%}}@media (max-width:490px){.page-inner mat-paginator,.page-inner mat-table.mat-table{width:200%}}"]
            }] }
];
/** @nocollapse */
ContactLogTableComponent.ctorParameters = () => [
    { type: ContactLogService, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => ContactLogService)),] }] },
    { type: ActivatedRoute, decorators: [{ type: Inject, args: [forwardRef((/**
                     * @return {?}
                     */
                    () => ActivatedRoute)),] }] }
];
ContactLogTableComponent.propDecorators = {
    dataSource: [{ type: Input }],
    Partners: [{ type: Input }],
    displayedColumns: [{ type: Input }],
    customColumns: [{ type: Input }],
    action: [{ type: Output }],
    paginator: [{ type: ViewChild, args: [MatPaginator, { static: true },] }],
    sort: [{ type: ViewChild, args: [MatSort, { static: true },] }]
};
if (false) {
    /** @type {?} */
    ContactLogTableComponent.prototype.dataSource;
    /** @type {?} */
    ContactLogTableComponent.prototype.Partners;
    /** @type {?} */
    ContactLogTableComponent.prototype.displayedColumns;
    /** @type {?} */
    ContactLogTableComponent.prototype.customColumns;
    /** @type {?} */
    ContactLogTableComponent.prototype.action;
    /** @type {?} */
    ContactLogTableComponent.prototype.paginator;
    /** @type {?} */
    ContactLogTableComponent.prototype.sort;
    /** @type {?} */
    ContactLogTableComponent.prototype.contactLogFilter;
    /**
     * @type {?}
     * @private
     */
    ContactLogTableComponent.prototype.service;
    /**
     * @type {?}
     * @private
     */
    ContactLogTableComponent.prototype._route;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// services
class CRMCompModule {
}
CRMCompModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    MatDatepickerModule,
                    MatButtonModule,
                    MatIconModule,
                    MatRippleModule,
                    MatSlideToggleModule,
                    MatTableModule,
                    MatSortModule,
                    MatTooltipModule,
                    FlexLayoutModule,
                    MatMenuModule,
                    MatCheckboxModule,
                    HttpClientModule,
                    OverlayModule,
                    MatPaginatorModule,
                    CdkTableModule,
                    TranslateModule.forChild()
                ],
                declarations: [
                    AccountTableComponent, RelationTableComponent, ContactLogTableComponent
                ],
                exports: [
                    AccountTableComponent, RelationTableComponent, ContactLogTableComponent
                ],
                providers: [],
                entryComponents: [],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AccountQueryStore, AccountTableComponent, CRMCompModule, ContactLogQueryStore, ContactLogTableComponent, RelationQueryStore, RelationTableComponent };
//# sourceMappingURL=yukawa-chain-crm-angular-comp.js.map
